@@ -1,4 +1,4 @@
-SOURCE_TEMPLATE="""
+
 def hello(world):
     return 'Hello, ' + world
-"""
+
